@@ -19,7 +19,7 @@ pub fn generate(env: &Env, root_path: &Path, mod_rs: &mut Vec<String>) {
 
         let mut path = root_path.join(&mod_name);
         path.set_extension("rs");
-        info!("Generating file {:?}", path);
+        info!("Generating file {path:?}");
 
         save_to_file(path, env.config.make_backup, |w| {
             super::record::generate(w, env, record_analysis)
