@@ -36,12 +36,6 @@ fn generate_build_script(w: &mut dyn Write, env: &Env, split_build_rs: bool) ->
         general::start_comments(w, &env.config)?;
         writeln!(w)?;
     }
-    writeln!(
-        w,
-        "{}",
-        r#"#[cfg(not(docsrs))]
-use std::process;"#
-    )?;
 
     if split_build_rs {
         writeln!(w)?;
@@ -52,14 +46,15 @@ use std::process;"#
         w,
         "{}",
         r#"
-#[cfg(docsrs)]
-fn main() {} // prevent linking libraries to avoid documentation failure
-
-#[cfg(not(docsrs))]
 fn main() {
+    if std::env::var("DOCS_RS").is_ok() {
+        // prevent linking libraries to avoid documentation failure
+        return;
+    }
+
     if let Err(s) = system_deps::Config::new().probe() {
         println!("cargo:warning={s}");
-        process::exit(1);
+        std::process::exit(1);
     }
 }
 "#
