@@ -52,7 +52,7 @@ impl Library {
                     (Some(name), Some(ver)) => {
                         if self.find_namespace(name).is_none() {
                             let lib = format!("{name}-{ver}");
-                            if libs.iter().any(|x| *x == lib) {
+                            if libs.contains(&lib) {
                                 return Err(format!(
                                     "`{}` includes itself (full path:`{}`)!",
                                     lib,
@@ -80,6 +80,7 @@ impl Library {
                 std::mem::take(&mut packages),
                 std::mem::take(&mut includes),
             ),
+            "format" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -212,6 +213,7 @@ impl Library {
                 .map(|v| vfns.push(v)),
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
             "union" => self
                 .read_union(parser, ns_id, elem, Some(class_name), Some(c_type))
@@ -386,6 +388,7 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             "method-inline" => parser.ignore_element(),
@@ -564,6 +567,7 @@ impl Library {
             "source-position" => parser.ignore_element(),
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -643,6 +647,7 @@ impl Library {
                     })
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
+            "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -718,6 +723,7 @@ impl Library {
                 }),
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "virtual-method" => self
                 .read_virtual_method(parser, ns_id, elem)
                 .map(|v| vfns.push(v)),
@@ -774,6 +780,7 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
@@ -825,6 +832,7 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
@@ -898,6 +906,7 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
@@ -959,6 +968,7 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -1000,6 +1010,7 @@ impl Library {
         parser.elements(|parser, elem| match elem.name() {
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -1211,6 +1222,8 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
+            "source-position" => parser.ignore_element(),
             "attribute" => parser.ignore_element(),
             _ => Err(parser.unexpected_element(elem)),
         })?;
@@ -1398,6 +1411,8 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
+            "doc-version" => parser.ignore_element(),
+            "source-position" => parser.ignore_element(),
             "attribute" => {
                 if let (Some(name), Some(value)) = (elem.attr("name"), elem.attr("value")) {
                     match name {
@@ -1492,7 +1507,11 @@ impl Library {
                     "<type> element is missing an inner element type",
                     elem.position(),
                 ))
-            } else if type_name == "gboolean" && c_type.as_deref() == Some("_Bool") {
+            } else if type_name == "gboolean"
+                && c_type
+                    .as_ref()
+                    .is_some_and(|c_type| c_type == "_Bool" || c_type == "bool")
+            {
                 Ok((self.find_or_stub_type(ns_id, "bool"), c_type, array_length))
             } else {
                 Ok((
